@@ -28,8 +28,9 @@ def is_create_retryable_error(exc: Exception) -> bool:
 def log(objname: str, obj: dict=None) -> None:
     logger.log(VERBOSE1, '%s:\n%s', objname, pformat(obj if obj else config.user.get(objname, {})))
 
-def target(key: str, names: Iterable[str], operator='IS', match_type: str='EXACT') -> dict:
-    tgt_key = TargetingKey(name=key).fetchone(create=True)
+def target_fetch(key: str, names: Iterable[str], operator='IS', match_type: str='EXACT',
+                 reportableType: str='OFF') -> dict:
+    tgt_key = TargetingKey(name=key, reportableType=reportableType).fetchone(create=True)
     recs = []
     for name in names:
         recs.append(dict(
@@ -38,7 +39,7 @@ def target(key: str, names: Iterable[str], operator='IS', match_type: str='EXACT
             displayName=name,
             matchType=match_type,
         ))
-    tgt_values = TargetingValues(key_id=tgt_key['id']).fetch(create=True, recs=recs, validate=True)
+    tgt_values = TargetingValues(key_id=tgt_key['id'], name=list(names)).fetch(create=True, recs=recs, validate=True)
     return dict(
         key=tgt_key,
         operator=operator,
@@ -63,6 +64,7 @@ class GAMLineItems:
             bidder=bidder,
             media_type=media_type,
         )
+        _ = self.advertiser
 
     @property
     def is_size_override(self) -> bool:
@@ -74,8 +76,14 @@ class GAMLineItems:
         if self._advertiser is None:
             cfg = render_cfg('advertiser', self.bidder)
             log('advertiser', obj=cfg)
-            self._advertiser = \
-              Advertiser(name=cfg['name']).fetchone(create=True)
+            if cfg.get('id'):
+                self._advertiser = Advertiser(id=cfg['id']).fetchone()
+                if not 'id' in self._advertiser:
+                    raise ResourceNotFound(f"Advertiser id: {cfg['id']} was not found")
+            else:
+                self._advertiser = \
+                  Advertiser(name=cfg['name'],
+                             type=cfg.get('type', config.app['mgr']['advertiser']['type'])).fetchone(create=True)
         return self._advertiser
 
     @retry(retry_on_exception=is_create_retryable_error, stop_max_attempt_number=5, wait_fixed=2000)
@@ -170,7 +178,9 @@ class GAMLineItems:
     @property
     def targeting_key(self) -> dict:
         if self._targeting_key is None:
-            self._targeting_key = target(self.bidder.targeting_key, config.cpm_names())
+            reportableType=config.targeting_bidder_key_config().get('reportableType', 'OFF')
+            self._targeting_key = target_fetch(
+                self.bidder.targeting_key, config.cpm_names(), reportableType=reportableType)
         return self._targeting_key
 
 class GAMConfig:
@@ -293,8 +303,12 @@ class GAMConfig:
     @property
     def targeting_custom(self) -> List[dict]:
         if self._targeting_custom is None:
-            self._targeting_custom = [target(k, v, operator=op)
-                                      for k, v, op in config.custom_targeting_key_values()]
+            self._targeting_custom = [target_fetch(
+                D_['name'],
+                D_['values'],
+                operator=D_['operator'],
+                reportableType=D_['reportableType']) \
+                for D_ in config.custom_targeting_key_values()]
         return self._targeting_custom
 
     @property
